"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WireMock = void 0;
const axios_1 = require("axios");
const RequestModel_1 = require("./RequestModel");
const ResponseModel_1 = require("./ResponseModel");
const utils_1 = require("./utils");
const WIREMOCK_MAPPINGS_URL = '__admin/mappings';
const WIREMOCK_REQUESTS_URL = '__admin/requests';
const WIREMOCK_SCENARIO_URL = '__admin/scenarios';
const HEADERS = { 'Content-Type': 'application/json' };
class WireMock {
    constructor(baseUrl) {
        this.baseUrl = baseUrl;
    }
    async register(request, response, features) {
        const mockedRequest = (0, RequestModel_1.createWireMockRequest)(request, features);
        const mockedResponse = (0, ResponseModel_1.createWireMockResponse)(response, features);
        let mock = {
            request: mockedRequest,
            response: mockedResponse,
        };
        if (features === null || features === void 0 ? void 0 : features.stubPriority) {
            mock.priority = features.stubPriority;
        }
        if (features === null || features === void 0 ? void 0 : features.scenario) {
            mock = { ...mock, ...features.scenario };
        }
        if (features === null || features === void 0 ? void 0 : features.webhook) {
            mock.postServeActions = [
                {
                    name: 'webhook',
                    parameters: {
                        method: features.webhook.method,
                        url: features.webhook.url,
                        ...(features.webhook.headers && { headers: features.webhook.headers }),
                        ...(features.webhook.body && {
                            body: (0, utils_1.getWebhookBody)(features.webhook.body),
                        }),
                        ...(features.webhook.delay && {
                            delay: (0, utils_1.getWebhookDelayBody)(features.webhook.delay),
                        }),
                    },
                },
            ];
        }
        const wiremockResponse = await axios_1.default.post(this.makeUrl(WIREMOCK_MAPPINGS_URL), mock, {
            headers: HEADERS,
        });
        return wiremockResponse.data;
    }
    clearAll() {
        return Promise.all([this.clearAllMappings(), this.clearAllRequests()]);
    }
    clearAllExceptDefault() {
        return Promise.all([this.resetMappings(), this.clearAllRequests()]);
    }
    async clearAllMappings() {
        return await axios_1.default.delete(this.makeUrl(WIREMOCK_MAPPINGS_URL));
    }
    async clearAllRequests() {
        return await axios_1.default.delete(this.makeUrl(WIREMOCK_REQUESTS_URL));
    }
    async deleteMapping(id) {
        return await axios_1.default.delete(this.makeUrl(WIREMOCK_MAPPINGS_URL + '/' + id));
    }
    async getAllMappings() {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_MAPPINGS_URL));
        const responseJson = response.data;
        return responseJson.mappings;
    }
    async getAllRequests() {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_REQUESTS_URL));
        const responseJson = response.data;
        return responseJson.requests;
    }
    async getAllScenarios() {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_SCENARIO_URL));
        const responseJson = response.data;
        return responseJson.scenarios;
    }
    async getMapping(id) {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_MAPPINGS_URL + '/' + id));
        return await response.data;
    }
    async getRequestsForAPI(method, endpointUrl) {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_REQUESTS_URL));
        const body = response.data;
        return (body.requests
            .filter((r) => (0, utils_1.filterRequest)(method, endpointUrl, r)));
    }
    async getUnmatchedRequests() {
        const response = await axios_1.default.get(this.makeUrl(WIREMOCK_REQUESTS_URL + '/unmatched'));
        const body = response.data;
        return body.requests;
    }
    async resetAllScenarios() {
        return await axios_1.default.post(this.makeUrl(WIREMOCK_SCENARIO_URL + '/reset'));
    }
    async resetMappings() {
        return await axios_1.default.post(this.makeUrl(WIREMOCK_MAPPINGS_URL + '/reset'));
    }
    makeUrl(endpoint) {
        return new URL(endpoint, this.baseUrl).href;
    }
}
exports.WireMock = WireMock;
//# sourceMappingURL=WireMock.js.map